@@ -50,6 +50,7 @@ TimsData::TimsData(QDir timsDataDirectory) : m_timsDataDirectory(timsDataDirecto
   mpa_mzCalibrationStore = new MzCalibrationStore();
   if(!m_timsDataDirectory.exists())
     {
+      qDebug();
       throw PappsoException(QObject::tr("ERROR TIMS data directory %1 not found")
                               .arg(m_timsDataDirectory.absolutePath()));
     }
@@ -279,9 +280,11 @@ TimsData::fillFrameIdDescrList()
   qDebug();
   QSqlDatabase qdb = openDatabaseConnection();
 
-  QSqlQuery q =
-    qdb.exec(QString("SELECT Id, NumScans FROM "
-                     "Frames ORDER BY Id"));
+  QSqlQuery q(qdb);
+  q.prepare(
+    QString("SELECT Id, NumScans FROM "
+            "Frames ORDER BY Id"));
+  q.exec();
   if(q.lastError().isValid())
     {
 
@@ -481,12 +484,14 @@ TimsData::getTimsMS1FrameIdsInRtRange(double rt_begin, double rt_end) const
     rt_begin = 0;
   std::vector<std::size_t> tims_frameid_list;
   QSqlDatabase qdb = openDatabaseConnection();
-  QSqlQuery q      = qdb.exec(QString("SELECT Frames.Id FROM Frames WHERE "
-                                      "Frames.MsMsType=0 AND (Frames.Time>=%1) "
-                                      "AND (Frames.Time<=%2) ORDER BY "
-                                      "Frames.Time;")
-                           .arg(rt_begin)
-                           .arg(rt_end));
+  QSqlQuery q(qdb);
+  q.prepare(QString("SELECT Frames.Id FROM Frames WHERE "
+                    "Frames.MsMsType=0 AND (Frames.Time>=%1) "
+                    "AND (Frames.Time<=%2) ORDER BY "
+                    "Frames.Time;")
+              .arg(rt_begin)
+              .arg(rt_end));
+  q.exec();
   if(q.lastError().isValid())
     {
 
@@ -519,12 +524,15 @@ TimsData::getTimsMS2FrameIdsInRtRange(double rt_begin, double rt_end) const
     rt_begin = 0;
   std::vector<std::size_t> tims_frameid_list;
   QSqlDatabase qdb = openDatabaseConnection();
-  QSqlQuery q      = qdb.exec(QString("SELECT Frames.Id FROM Frames WHERE "
-                                      "Frames.MsMsType=8 AND "
-                                      "(Frames.Time>=%1) AND (Frames.Time<=%2) ORDER BY "
-                                      "Frames.Time;")
-                           .arg(rt_begin)
-                           .arg(rt_end));
+
+  QSqlQuery q(qdb);
+  q.prepare(QString("SELECT Frames.Id FROM Frames WHERE "
+                    "Frames.MsMsType=8 AND "
+                    "(Frames.Time>=%1) AND (Frames.Time<=%2) ORDER BY "
+                    "Frames.Time;")
+              .arg(rt_begin)
+              .arg(rt_end));
+  q.exec();
   if(q.lastError().isValid())
     {
 
@@ -812,10 +820,13 @@ TimsData::getTicChromatogram() const
 
 
   QSqlDatabase qdb = openDatabaseConnection();
-  QSqlQuery q =
-    qdb.exec(QString("SELECT Time, SummedIntensities "
-                     "FROM Frames WHERE MsMsType = 0 "
-                     "ORDER BY Time;"));
+  QSqlQuery q(qdb);
+
+  q.prepare(
+    QString("SELECT Time, SummedIntensities "
+            "FROM Frames WHERE MsMsType = 0 "
+            "ORDER BY Time;"));
+  q.exec();
 
   if(q.lastError().isValid())
     {
